#
# spec file for package perl-Curses
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Curses
Version:        1.36
Release:        1.2
Summary:        Terminal screen handling and optimization
License:        Artistic-1.0
Group:          Development/Libraries/Perl
Url:            http://cpan.org/modules/by-module/Curses/
Source0:        Curses-%{version}.tar.gz
Source1:        https://cpan.metacpan.org/authors/id/G/GI/GIRAFFED/Curses-%{version}.tar.gz
BuildRequires:  ncurses-devel
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       Curses
Provides:       perl_cur
Obsoletes:      perl_cur
%{perl_requires}

%description
Curses is the interface between Perl and your system's curses(3) library.
For descriptions on the usage of a given function, variable, or constant,
consult your system's documentation, as such information invariably varies
(:-) between different curses(3) libraries and operating systems. This
document describes the interface itself, and assumes that you already know
how your system's curses(3) library works.

%prep
%setup -q -n Curses-%{version}

%build
CURSES_LDFLAGS="-lncursesw" CURSES_CFLAGS="-I/usr/include/ncursesw/" perl Makefile.PL PANELS MENUS OPTIMIZE="%{optflags} -Wall"
make %{?_smp_mflags}

%check
make %{?_smp_mflags} test

%install
make DESTDIR=%{buildroot} install_vendor
%perl_process_packlist
chmod a-x test.syms demo.form

%files
%license Copying
%doc README Artistic demo demo2 demo.form demo.menu demo.panel HISTORY list.syms MAINTENANCE README test.syms
%{_mandir}/man3/*
%{perl_vendorarch}/Curses.pm
%{perl_vendorarch}/auto/Curses

%changelog
* Wed Sep 12 2018 pmonrealgonzalez@suse.com
- updated to 1.36 (Released August 14, 2016)
  Fix the GNU Hurd thing from 1.35 by including the hints file in the
  manifest.
  New in 1.35 (Released July 11, 2016)
  Added hints file for GNU Hurd ($OSNAME == 'gnu').  From Pino Toscano.
  New in 1.34 (Released April 2, 2016)
  Several bugs fixed in demo programs (which also function as the
  documentation) for forms and menus and comments added explaining need to
  keep Perl variables around to avoid invalid memory references.
  New in 1.33 (Released October 3, 2015)
  Package contains META files.
- Cleaned with spec-cleaner
* Fri Feb  6 2015 coolo@suse.com
- updated to 1.32
  Makefile.PL: if /usr/include/ncurses/ncurses.h exists, use Ncurses regardless
  of what the $guess_cfg table says for the OS at hand.  This fixes the former
  hybrid approach which didn't work for a Solaris 11 system that has both
  Ncurses and BSD curses.
  Typographical error in documentation fixed.
  New in 1.31 (Released April 26, 2014)
  Fix compile failure with some Curses libraries, introduced in
  1.29 - undefined KEY_CODE_YES.
  Fix documentation: wide character functions exist back to Perl 5.6,
  not 5.16.
  New in 1.30 (Released April 19, 2014)
  Fix build failure: Use older substitutes if Perl is too old to have
  the 'utf8_to_uvchr_buf' function they use; don't include the wide character
  functions if Perl is even too old to have the substitutes.  Broken in 1.29.
  Fix "constant not provided by your vendor" message when you refer to a
  function that does not exist in the Curses module.
  Minor fixes to documentation of new wide character functions.
  Fix warning about extra argument to c_setmevent .
  Fix documentation for "not defined in your Curses library" errors.
  (broken in 1.28).
  Fix demo programs' recognition of "not defined in your Curses library"
  errors (broken in 1.28).
  New in 1.29 (Released April 6, 2014)
  Add an alternate set of functions (getchar, ungetchar, getstring,
  instring, addstring, insstring) providing a more Perl-like interface,
  converting from and to Perl strings (instead of passing data to the C
  library verbatim) and using wide character functions if available in the
  underlying curses library.
  Written by Edgar Fu201337, Mathematisches Institut der Uni Bonn,
  <ef@math.uni-bonn.de>
* Fri Nov 18 2011 coolo@suse.com
- use original tar.gz
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Tue Feb  9 2010 coolo@novell.com
- update to 1.28
  * Disable Curses::Var::STORE.  It doesn't work (doesn't even compile) with
    newer Ncurses (due to updates to make Ncurses reentrant).  One can
    re-enable it by defining ALLOW_VARS_STORE in c-config.h.
  * Improve "not provided by your vendor" message.
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Feb 23 2009 anicka@suse.cz
- update to 1.27
  * Extraneous .i and .s files in 1.26 removed.  'make clean' cleans
  all .i and .s too.
  * 'gen' directory is replaced by gen.tar file, so CPAN doesn't
    index the stuff in there.  That directory is stuff for developing
    the Curses package, not stuff for users.
  * newterm() is available and putwin() and getwin() work in newer
  Perl (with PerlIO). We now use PerlIO_findFile().
* Wed Sep 10 2008 anicka@suse.cz
- update to 1.24
  * Export KEY_RESIZE, KEY_EVENT.
  * For Netbsd, allow both Netbsd and BSD guesses via CURSES_LIBTYPE,
  and default to Ncurses.
  * Add guess capability for Dragonfly.
* Mon Mar 10 2008 anicka@suse.cz
- update to 1.23
  * Fix crash of Makefile.PL on Windows.
  * Don't undefine 'bool' macro in c-darwin hints file.
  * Fix missing comment delimiter.
* Mon Nov 19 2007 anicka@suse.cz
- update to 1.19
- add -lpanel and -lmenu
  * Use Ncursesw (Ncurses with wide character functions) instead of
    Ncurses if available.
  * Change all sv_isa() to sv_derived_from() so you can use
    subclasses.
  * bugfixes, test fixes
* Thu Mar 29 2007 rguenther@suse.de
- add ncurses-devel BuildRequires
* Sat Mar 10 2007 mmarek@suse.cz
- link with ncursesw.so to make UTF8 output work
* Fri Jul 14 2006 anicka@suse.cz
- update to 1.14
  * Make demo.form work on 64 bit machine.
  * Add some narration to Makefile.PL to help with diagnosis.
  * Move undef of 'instr' from individual hint files to Curses.c
    and add explanation.
  * Some kind of build fix to get panels, forms, and menu functions
    to build.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Aug  1 2005 cthiel@suse.de
- update to version 1.12
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Fri Aug  9 2002 mls@suse.de
- use sv_isa instead of Perl_sv_isa for threaded perl
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Fri Aug  3 2001 rvasice@suse.cz
- update to version 1.06
- spec file cleanup
* Tue Nov 14 2000 cihlar@suse.cz
- clean up spec file
* Thu Nov  2 2000 grimmer@suse.de
- renamed from perl_cur to perl-Curses
- spec file cleanups
* Tue Aug 22 2000 cihlar@suse.cz
- update to version 1.05
- added BuildRoot
- bzipped sources
* Thu Jan 20 2000 ro@suse.de
- use macro for mandir
* Mon Nov  8 1999 choeger@suse.de
- first version
